@@ -1,10 +1,9 @@
 #! /usr/bin/env ruby
-require 'dbus'
+require "dbus"
 
 bus = DBus::SystemBus.instance
 nm_service = bus["org.freedesktop.NetworkManager"]
-network_manager_object = nm_service.object("/org/freedesktop/NetworkManager")
-network_manager_object.introspect
+network_manager_object = nm_service["/org/freedesktop/NetworkManager"]
 nm_iface = network_manager_object["org.freedesktop.NetworkManager"]
 
 # read a property
@@ -16,4 +15,4 @@ else
 end
 puts "Toggling wireless"
 # write a property
-nm_iface["WirelessEnabled"] = ! enabled
+nm_iface["WirelessEnabled"] = !enabled
